@@ -8,6 +8,9 @@ class ModelNotRegistered(StdNetException):
 registered with a :class:`stdnet.backends.BackendDataServer`. Check :func:`stdnet.orm.register` for details.'''
     pass
 
+class AlreadyRegistered(StdNetException):
+    pass
+
 class ObjectNotValidated(StdNetException):
     '''A :class:`StdNetException` raised when an instance of a :class:`stdnet.orm.StdModel` fails to validate
 (probably required :class:`stdnet.orm.Field` are missing from the instance).'''
@@ -37,6 +40,7 @@ class QuerySetError(StdNetException):
 evaluation.'''
     pass
 
-class ObjectNotFund(QuerySetError):
+class ObjectNotFound(QuerySetError):
     '''A :class:`QuerySetError` raised when an object is not found.'''
-    pass
\ No newline at end of file
+    pass
+
