@@ -12,6 +12,7 @@ from .base import StdNetType, AlreadyRegistered
 logger = logging.getLogger('stdnet.mapper')
 
 __all__ = ['clearall',
+           'flush_models',
            'register',
            'unregister',
            'model_iterator',
@@ -29,6 +30,34 @@ def clearall(exclude = None):
             meta.cursor.clear()
 
 
+def models_from_names(names):
+    global _GLOBAL_REGISTRY
+    s = set(names)
+    for m in _GLOBAL_REGISTRY:
+        if str(m._meta) in s:
+            yield m
+    
+
+def flush_models(includes = None, excludes = None):
+    '''Utility for flushing models data.
+It removes all keys associated with models.'''
+    global _GLOBAL_REGISTRY
+    if includes:
+        includes = list(models_from_names(includes))
+    else:
+        includes = _GLOBAL_REGISTRY
+    if excludes:
+        excludes = set(models_from_names(excludes))
+    else:
+        excludes = set()
+    flushed = []
+    for model in includes:
+        if model not in excludes:
+            model.flush()
+            flushed.append(str(model._meta))
+    return flushed
+            
+
 def register(model, backend = None, keyprefix = None, timeout = None,
              ignore_duplicates = True):
     '''Register a :class:`stdnet.orm.StdModel`
