@@ -5,11 +5,13 @@ from stdnet.utils import zip, UnicodeMixin
 from stdnet import dispatch
 
 from .base import StdNetType
+from .globals import get_model_from_hash 
 from .signals import *
 
 
 __all__ = ['StdModel',
            'StdNetType',
+           'from_uuid',
            'model_to_dict']
 
 
@@ -86,7 +88,7 @@ otherwise a :class:`stdnet.exceptions.ModelNotRegistered` exception will raise.'
         if not self.id:
             raise self.DoesNotExist('Object not saved. Cannot obtain universally unique id')
         return '{0}.{1}'.format(self._meta.hash,self.id)
-        
+    
     def __eq__(self, other):
         if other.__class__ == self.__class__:
             return self.id == other.id
@@ -158,8 +160,39 @@ If count is a dictionary, the method
 will enumerate the number of object to delete. without deleting them.'''
         return cls._meta.flush(count)
     
+    # PICKLING SUPPORT
+    
+    def __getstate__(self):
+        return (self.id, self.todict())
+    
+    def __setstate__(self, state):
+        id,data = state
+        meta = self._meta
+        field = meta.pk
+        setattr(self,'id',field.to_python(id))
+        for field in meta.scalarfields:
+            name = field.attname
+            if name in data:
+                value = data[name]
+            else:
+                value = None
+            setattr(self,name,field.to_python(value))
+        self.afterload()
+    
 
-
+def from_uuid(uuid):
+    '''Retrieve an instance of a :class:`stdnet.orm.StdModel`
+from an universal unique identifier *uuid*. If the *uuid* does not match any
+instance an exception will raise.'''
+    elems = uuid.split('.')
+    if len(elems) == 2:
+        model = get_model_from_hash(elems[0])
+        if not model:
+            raise StdModel.DoesNotExist('model id "{0}" not available'.format(elems[0]))
+        return model.objects.get(id = elems[1])
+    raise StdModel.DoesNotExist('uuid "{0}" not recognized'.format(uuid))
+    
+    
 def model_to_dict(instance, fields = None, exclude = None):
     if isinstance(instance,StdModel):
         return instance.todict()
