@@ -1,13 +1,14 @@
 from stdnet.lib import redis
-from stdnet import test
-
-DBTEST = 13
+from stdnet import test, getdb
+from stdnet.conf import settings
 
 
 ResponseError = redis.ResponseError
 
 def makeredis(pool = None):
-    return redis.Redis(host='localhost', port=6379, db=DBTEST, connection_pool=pool)
+    cursor = getdb(settings.DEFAULT_BACKEND)
+    return cursor.redispy
+    #return redis.Redis(host='localhost', port=6379, db=DBTEST, connection_pool=pool)
 
 
 class BaseTest(test.TestCase):
